@@ -113,6 +113,7 @@ public class ToolBarPanel extends ToolBar {
 		// layer export
 		exportButton = new Button("", Images.iconExport());
 		exportButton.setToolTip(EXPORT_TOOLTIP);
+		exportButton.setSize(32, 32);
 		Menu menuExport = new Menu();
 		menuExport.setStyleName("gisViewerMenu");
 		int i=0;
@@ -180,7 +181,7 @@ public class ToolBarPanel extends ToolBar {
 		button.setIcon(img);
 //		button.addStyleName("iconOpenlayersToolbar");
 		button.setToolTip(toolTip);
-//		button.setSize(25, 25);
+		button.setSize(32, 32);
 	}
 
 
@@ -198,10 +199,12 @@ public class ToolBarPanel extends ToolBar {
 
 
 	private void setZoomInToggle() {
+		//setUpBotton(zoomInToggle, Images.iconZoomIn(), ZOOM_IN_TOOLTIP);
 		zoomInToggle = new ToggleButton();
 		zoomInToggle.setIcon(Images.iconZoomIn());
 		zoomInToggle.setToolTip(ZOOM_IN_TOOLTIP);
-//TODO
+		zoomInToggle.setSize(32, 32);
+
 		//zoomInToggle.setToggleGroup(TOGGLE_GROUP);
 		zoomInToggle.addSelectionListener(new SelectionListener<ButtonEvent>() {
 			@Override
@@ -228,6 +231,7 @@ public class ToolBarPanel extends ToolBar {
 		setUpBotton(panToggle, Images.iconPan(), PAN_TOOLTIP);
 		panToggle.toggle(true);
 		panToggle.setToggleGroup(TOGGLE_GROUP);
+		//panToggle.setSize(32, 32);
 		panToggle.addSelectionListener(new SelectionListener<ButtonEvent>() {
 			@Override
 			public void componentSelected(ButtonEvent be) {
